---
title: "Collapse and Continuity: A multi-proxy reconstruction of settlement organization and population trajectories in the Northern Fertile Crescent during the 4.2kya Rapid Climate Change event (dataset and R scripts) README"
authors: Alessio Palmisano, Dan Lawrence, and Michelle W. de Gruchy
dataset_version: 1.0
---

# Collapse and Continuity: A multi-proxy reconstruction of settlement organization and population trajectories in the Northern Fertile Crescent during the 4.2kya Rapid Climate Change event (dataset and R scripts)
The present digital archive is the outcome of the paper: Lawrence, D., Palmisano, A., and de Gruchy, M.W., in press. Collapse and Continuity: A multi-proxy reconstruction of settlement organization and population trajectories in the Northern Fertile Crescent during the 4.2kya Rapid Climate Change event. PLoS ONE. 

The dataset included here provides a collection of 920 radiocarbon dates and 1070 sites from archaeological surveys. In addition, the digital archive related to this paper provides reproducible analyses in the form of three scripts written in R statistical computing language. 

NB:the present digital archive does not include the unpublished radiocarbon dates from the site Tell Nebi Mend provided by Graham Philip for the paper published in the journal PloS ONE. They will be published separately in forthcoming publications. Therefore, the following figures reproduced by using the R scripts and data here provided will slightly differ from the ones published in the original paper: Figs. 2-3, and 7.    
However, the outputs generated by using the original dataset used in the paper are stored in the file "radiocarbon.RData" within the folder "rda". If you use the outputs from this RData file, you will be able to reproduce the identical figures published in the paper.   

The 920 radiocarbon dates of the present digital archive are a subset of the following dataset: Palmisano, Alessio, Lawrence, Dan, de Gruchy, Michelle W., Bevan, Andrew, & Shennan, Stephen. (2020). Holocene regional population dynamics and climatic trends in the Near East: a first comparison using archaeo-demographic proxies (dataset and R scripts) [Data set]. Zenodo. http://doi.org/10.5281/zenodo.4322979


###### CONTENTS ######

#R_scripts
* Script for calibrating and analysing radiocarbon dates and for reproducing Figures 2-3 (radiocarbon.R).
* Script for modelling population dynamics by using archaeological survey data and for reproducing Figure 4 (settlements.R).
* Script for modelling population dynamics by using archaeological survey data, for calculating the Pearson's correlations between archaeo-demographic proxies (as shown in Tables 1-4) and for reproducing Figures 5 and 7 (urban_sites.R).

#Folder "shp"
*ESRI polygon shapefile of the World countries (countries.shp).
*ESRI polygon shapefile of lakes in South-West Asia (lakes.shp).
*ESRI polyline shapefile of rivers in South-West Asia (rivers.shp).
*ESRI polygon shapefile of the spatial window used for plotting the density map of radiocarbon dates in Fig. 2a (region.shp).
*ESRI polygon shapefile of the study area (study_area.shp).
*ESRI polygon shapefile used to select the sites according to the annual rainfall zone (rainfall_zone.shp)

#Folder "csv"
* csv file of radiocarbon dates (dates.csv).
* csv file of settlement data from archaeological surveys (settlements.csv)
* csv file of urban sites from archaeological surveys and excavations (urban_sites.csv)
* A .txt file providing the field description for the attributes of the radiocarbon dates (dates_key.txt).
* A .txt file providing the field description for the attributes of the archaeological settlement data (settlements_key.txt).
* A .txt file providing the field description for the attributes of the urban sites (urban_sites_key.txt).
* A .txt file providing a list of references from which the radiocarbon dates were collected (references_dates.txt).
* A .txt file providing a list of references from which the archaeological settlement data were collected (references_settlements.txt).

#Folder "rda"
* RData file storing the outputs (e.g. SPDs, null models) generated via the original radiocarbon dataset used in the paper published in PloS One (radiocarbon.RData).
* RData file storing the population dynamics inferred by using the settlement data from archaeological surveys (settlements.RData).

#Folder "pdf"
an empty folder where to store the figures outputted via the R scripts provided here. 


###### Licences
Dataset: CC-BY (http://creativecommons.org/licenses/by/4.0/)

Code: MIT (http://opensource.org/licenses/MIT year: 2020, copyright holder: Alessio Palmisano, Dan Lawrence, and Michelle W. de Gruchy. 

##### Dependencies
R version 4.0.3 (2020-10-10)

Packages
* doParallel (v. 1.0.16)
* maps (v. 3.3.0)
* maptools (v. 1.0-2)
* raster (v. 3.4-5)
* rcarbon (v. 1.4.1)
* rgdal (v. 1.5-18)
* rgeos (v. 0.5-5)
* spatstat (v. 1.64-1)


