# Install library if not installed -------------------------------------####
if (!('rcarbon' %in% installed.packages())){
  install.packages('rcarbon')
}

# Install library if not installed -------------------------------------####
if (!('doParallel' %in% installed.packages())){
  install.packages('doParallel')
}

# Install library if not installed -------------------------------------####
if (!('rgdal' %in% installed.packages())){
  install.packages('rgdal')
}

# Install library if not installed -------------------------------------####
if (!('spatstat' %in% installed.packages())){
  install.packages('spatstat')
}

# Install library if not installed -------------------------------------####
if (!('raster' %in% installed.packages())){
  install.packages('raster')
}

if (!('rgeos' %in% installed.packages())){
  install.packages('rgeos')
}

if (!('maptools' %in% installed.packages())){
  install.packages('maptools')
}

if (!('maps' %in% installed.packages())){
  install.packages('maps')
}


## Add libraries (you may need to install these first)
library(rcarbon)
library(doParallel)
library(rgdal)

## Load data
mydates <- read.csv("csv/dates.csv", header=TRUE, stringsAsFactors=FALSE, encoding="UTF-8",na.strings=c("NA",""),strip.white=TRUE)

# Load rainfall zones (from GIS-friendly, ESRI-format shapefiles  to "SpatialPolygonsDataFrame" objects in R)
rainfall<-readOGR("shp/rainfall_zone.shp", layer="rainfall_zone")
rainfall_above300mm<-rainfall[rainfall$Id==1,]#subset the rainfall zone with an annual rainfall greater than 300 mm
rainfall_below300mm<-rainfall[rainfall$Id==2,]#subset the rainfall zone with an annual rainfall below 300 mm

# Turn the whole date dataset into a spatial object than can be plotted on a map
# First, make sure the coordinates are treated as numbers
mydates$Longitude <- as.numeric(mydates$Longitude) 
mydates$Latitude <- as.numeric(mydates$Latitude)
# Then throw out any without coordinates
datesp <- mydates[!is.na(mydates$Longitude) & !is.na(mydates$Latitude),]
# Then designate the coordinate columns
coordinates(datesp) <- ~Longitude+Latitude
# Then stipulate that the coordinate system of this data is the same as the polygon data we have (i.e. unprojected latlon)
proj4string(datesp) <- proj4string(rainfall_above300mm)<-proj4string(rainfall_below300mm)

#Spatial query: selection of points (datesp) located within region (=1)
query_above300mm<-over(datesp,rainfall_above300mm)
query_below300mm<-over(datesp,rainfall_below300mm)

#convert vector into dataframe
above300mm<-as.data.frame(datesp)
below300mm<-as.data.frame(datesp)

#add column for storing spatial query's results
above300mm["query"]<-NA
below300mm["query"]<-NA

#update the column "query"
above300mm$query<-query_above300mm
below300mm$query<-query_below300mm

#subsetting the dates located in the study area
mydates_above300mm<-subset(above300mm, above300mm$query==1)
mydates_below300mm<-subset(below300mm, below300mm$query==2)

#add column for defining region
mydates_above300mm["Region"]<-1
mydates_below300mm["Region"]<-2

#aggregate all Radiocarbon dates
mydates<-rbind(mydates_above300mm,mydates_below300mm)
shortlived<-mydates[grep(paste(c("antler","bone","coprolite","seed","fruit","carpal","tooth", "grain", "twig", "grape","monocot","collagen", "dung", "teeth","tissue", "plant remains","stone","onion"),collapse="|"), mydates$Material),] # subselect shortlived samples

# Turn the whole date dataset into a spatial object than can be plotted on a map
# First, make sure the coordinates are treated as numbers
mydates$Longitude <- as.numeric(mydates$Longitude) 
mydates$Latitude <- as.numeric(mydates$Latitude)
mydates_above300mm$Longitude <- as.numeric(mydates_above300mm$Longitude) 
mydates_above300mm$Latitude <- as.numeric(mydates_above300mm$Latitude)
mydates_below300mm$Longitude <- as.numeric(mydates_below300mm$Longitude) 
mydates_below300mm$Latitude <- as.numeric(mydates_below300mm$Latitude)

# Then throw out any without coordinates
datesp<-mydates[!is.na(mydates$Longitude) & !is.na(mydates$Latitude),]
datesp_above300m <- mydates_above300mm[!is.na(mydates_above300mm$Longitude) & !is.na(mydates_above300mm$Latitude),]
datesp_below300m <- mydates_below300mm[!is.na(mydates_below300mm$Longitude) & !is.na(mydates_below300mm$Latitude),]

# Then designate the coordinate columns
coordinates(datesp) <- ~Longitude+Latitude
lonlat <- CRS("+init=epsg:4326") # LatLon WGS84
proj4string(datesp) <- lonlat
countries<-readOGR("shp/countries.shp", layer="countries")
datesp <- spTransform(datesp, proj4string(countries)) # UTM WGS84, zone 37 North
coordinates(datesp_above300m) <- ~Longitude+Latitude
coordinates(datesp_below300m) <- ~Longitude+Latitude

# Then stipulate that the coordinate system of this data is the same as the polygon data we have (i.e. unprojected latlon)
proj4string(datesp_above300m) <- proj4string(datesp_below300m)

## General SPD parameters
nsim <- 1000 # number of actual simulations (set to 5 for full demo)
ncores <- 6 # multi-core processing (set higher if available)
runm <- 50 #smoothing of SPDs
binh <- 50 #bin clustering
realstartBP <- 6000
realendBP <-3000
bracket <- 500
workingstartBP <- realstartBP+bracket
workingendBP <- realendBP-bracket
if (workingendBP<0){ workingendBP <- 0 }


## Calibrate dates (unnormalised for now)
alldates <- calibrate(x=mydates$CRA, errors=mydates$Error, calCurves='intcal20', method="standard", normalised=FALSE, ncores=ncores, calMatrix=TRUE)
shortlivedates <- calibrate(x=shortlived$CRA, errors=shortlived$Error, calCurves='intcal20', method="standard", normalised=FALSE, ncores=ncores, calMatrix=TRUE)
above300mm_dates<- calibrate(x=mydates_above300mm$CRA, errors=mydates_above300mm$Error, calCurves='intcal20', method="standard", normalised=FALSE, ncores=ncores, calMatrix=TRUE)
below300mm_dates<- calibrate(x=mydates_below300mm$CRA, errors=mydates_below300mm$Error, calCurves='intcal20', method="standard", normalised=FALSE, ncores=ncores, calMatrix=TRUE)

## Summed probability distributions (normalised and not)
bins <- binPrep(sites=mydates$SiteID, ages=mydates$CRA, h=binh)
allspdn<- spd(x=alldates, bins=bins, timeRange=c(workingstartBP,workingendBP), datenormalised=TRUE, runm=runm)
allspd<- spd(x=alldates, bins=bins, timeRange=c(workingstartBP,workingendBP), datenormalised=FALSE, runm=runm)

#short-lived radiocarbon samples
bins_shortlived <- binPrep(sites=shortlived$SiteID, ages=shortlived$CRA, h=binh)
allspd_shortlived <- spd(x=shortlivedates, bins=bins_shortlived, timeRange=c(workingstartBP,workingendBP), datenormalised=FALSE, runm=runm)

#region with annual rainfall greater than 300 mm
bins_above300m <- binPrep(sites=mydates_above300mm$SiteID, ages=mydates_above300mm$CRA, h=binh)
allspd_above300m <- spd(x=above300mm_dates, bins=bins_above300m, timeRange=c(workingstartBP,workingendBP), datenormalised=FALSE, runm=runm)

#region with annual rainfall below 300 mm
bins_below300m <- binPrep(sites=mydates_below300mm$SiteID, ages=mydates_below300mm$CRA, h=binh)
allspd_below300m <- spd(x=below300mm_dates, bins=bins_below300m, timeRange=c(workingstartBP,workingendBP), datenormalised=FALSE, runm=runm)


#Calculate the Pearson correlation coefficient between the unnormalised and normalised SPDS obtained calibrating all radiocarbon samples
cor.test(allspd$grid$PrDens, allspdn$grid$PrDens, method = "pearson")
#the two curves are highly correlated. rho=0.96, p-value <0.001

#Calculate the Pearson correlation coefficient between the SPD (unnormalised) obtained calibrating all radiocarbon samples and the SPD from short-lived radiocarbon dates
cor.test(allspd$grid$PrDens, allspd_shortlived$grid$PrDens, method = "pearson")
#the two curves are highly correlated. rho=0.96, p-value <0.001

#calculate the median of bins
bins.med<-binMed(x=alldates, bins=bins)

## Fit a logistic model and create a predicted SPD
# Generate a smoothed SPD
spd.smoothed = spd(alldates,timeRange=c(6000,3000),bins=bins,runm=runm)
# Start values should be adjusted depending on the observed SPD
logFit <- nls(PrDens~SSlogis(calBP, Asym, xmid, scale),data=spd.smoothed$grid,control=nls.control(maxiter=200),start=list(Asym=0.2,xmid=5500,scale=-100))
# Generate a data frame containing the fitted values
logFitDens=data.frame(calBP=spd.smoothed$grid$calBP,PrDens=SSlogis(input=spd.smoothed$grid$calBP,Asym=coefficients(logFit)[1],xmid=coefficients(logFit)[2],scal=coefficients(logFit)[3]))
# Use the modelTest function (returning the raw simulation output - see below)
logisticmod <- modelTest(alldates, errors=mydates$Error, bins=bins,nsim=nsim,timeRange=c(6000,3000), model="custom",predgrid=logFitDens, runm=runm, ncores=ncores, raw=TRUE)


#Test for Regional Departure from Global Pattern (CPU-intensive, set nsim to 5 to test)
set.seed(123)
perm<- permTest(x=alldates, bins=bins, marks=datesp$Region, timeRange=c(workingstartBP,workingendBP), runm=runm, nsim=nsim)



############################ Map the spatial intensity of radiocarbon dates #############################################

#load required libraries
library(spatstat)
library(rgdal)
library(raster)
library(rgeos)
library(maptools)
library(maps)

# Turn the whole date dataset into a spatial object than can be plotted on a map
# First, make sure the coordinates are treated as numbers
mydates$Longitude <- as.numeric(mydates$UTM_X) 
mydates$Latitude <- as.numeric(mydates$UTM_Y)
mydates_above300mm$Longitude <- as.numeric(mydates_above300mm$UTM_X) 
mydates_above300mm$Latitude <- as.numeric(mydates_above300mm$UTM_Y)
mydates_below300mm$Longitude <- as.numeric(mydates_below300mm$UTM_X) 
mydates_below300mm$Latitude <- as.numeric(mydates_below300mm$UTM_Y)

# Then throw out any without coordinates
datesp_utm <- mydates[!is.na(mydates$UTM_X) & !is.na(mydates$UTM_Y),]
datesp_utm_above300mm <- mydates_above300mm[!is.na(mydates_above300mm$UTM_X) & !is.na(mydates_above300mm$UTM_Y),]
datesp_utm_below300mm <- mydates_below300mm[!is.na(mydates_below300mm$UTM_X) & !is.na(mydates_below300mm$UTM_Y),]

# Then designate the coordinate columns
coordinates(datesp_utm) <- ~Longitude+Latitude
coordinates(datesp_utm_above300mm) <- ~Longitude+Latitude
coordinates(datesp_utm_below300mm) <- ~Longitude+Latitude
#Assign a coordinate reference system
crs(datesp_utm) <- CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0")
crs(datesp_utm_above300mm) <- CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0")
crs(datesp_utm_below300mm) <- CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0")


#load the study area and spatial datasets
window<-readOGR("shp/region.shp")
countries<-readOGR("shp/study_area.shp", layer = "study_area")
lakes<-readOGR("shp/lakes.shp", layer="lakes")
rivers<-readOGR("shp/rivers.shp", layer="rivers")
#reproject the CRS of the vector files
window<-spTransform(window,CRS=CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))
countries<-spTransform(countries,CRS=CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))
lakes<-spTransform(lakes,CRS=CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))
rivers<-spTransform(rivers,CRS=CRS("+proj=utm +zone=37 +datum=WGS84 +units=m +no_defs +ellps=WGS84 +towgs84=0,0,0"))

#Convert the window of analysis into a an owin class object
window <- as(window,"owin")

# Generate a spatial intensity map of dates
sbw <- 50000 # Gaussian bandwdith (1 sd in metres)
cellres <- 1000 # raster cell size (in metres)
mysetppp <- ppp(x=coordinates(datesp_utm)[,1],y=coordinates(datesp_utm)[,2],window=as.owin(window))
# you will get the following message "Warning message:data contain duplicated points". Skip it.  
alldens <- density(mysetppp, sigma=sbw, eps=cellres, edge=FALSE)
alldenstc <- plot(alldens, main="", box=FALSE, do.plot=FALSE)


# N.B.The generation of some SPDs and null models could be time consuming. So, you can load the RData file storing all the outputs generated via the R script here provided.
# This file contains the SPDs and the spatial intensity map generated by using the original dataset used in the paper.
# As explained in the file "README.md" the csv file "dates.csv" do not contain all the radiocarbon dates used in the PLOS One's paper since some of them are unpublished (the dates from Tell Nebi Mend) and kindly shared by Graham Philip.
load("rda/radiocarbon.RData")


#Plot Figure 2
pdf(file="pdf/Fig2.pdf", width=6, height=6.2)
layout(matrix(c(1,2,3,3,4,4), 3, 2, byrow=TRUE), widths=c(3,3,3,3,3,3), heights=c(1.6,1.6,2.8,2.8,1.8,1.8))
par(mar=c(0, 1, 0, 0)) #c(bottom, left, top, right)
plot(countries,col="gray80",border="white",xlim = c(-57698.7 , 885325 ),ylim = c(3603858 ,4207531))
plot(alldens, main="", box=FALSE, add=TRUE)
plot(countries,col=rgb(128, 128, 128,alpha=0, maxColorValue=255),border="white",xlim = c(-57698.7 , 885325 ),ylim = c(3603858 ,4207531), add=TRUE)
plot(lakes, col="white", border="NA", add=T)
plot(rivers, col="white", lwd=0.3,add=T)
points(datesp_utm_above300mm, pch=19, cex=0.3, col="limegreen")
points(datesp_utm_below300mm, pch=19, cex=0.3, col="red")
#draw the density legend
plot(alldenstc,vertical=TRUE, las=2, main="", xlim=c(-97000 ,-70000), ylim=c(3650000 ,3800000), add=TRUE, cex.axis=0.8, axis=FALSE)
text(x=-30000, y=3820000, labels="high", cex=0.8)
text(x=-30000, y=3640000, labels="low", cex=0.8)
text(30000, y=3730000, expression(paste(sigma," = 50 km")), cex=0.9, col="black", font=1)
text(x=-90000, y=4200000, labels="a", cex=1.1, font=2)
#draw the north arrow
xpos <- 185325
ypos <- 3600000
lines(c(xpos,xpos),c(3680000,3580000),col="black")
polygon(c(xpos,xpos-(10000),xpos,xpos+(10000),xpos),c((ypos+70000),(ypos+70000),(ypos+90000),(ypos+70000),(ypos+70000)), col="black")
text(xpos, ypos+25000, "N", cex=0.9, col="black", font=2)
#draw the scale bar
polygon(c(290000,290000,390000,390000),c(3600000,3620000,3620000,3600000), col="NA", border="black")
text(340000, y=3650000, "100 km", cex=0.9, col="black", font=1)
#plot the histogram showing the median of bins
par(mar=c(2, 2, 1, 2)) #c(bottom, left, top, right)
hist(bins.med,breaks = 50, main="Histogram of number of bins", xlab = "cal BP", cex.main=1, xlim=c(5890,3111)) # histogram of number ob bins grouped for 500 years
mtext("b",1, -10.4, at=6100, adj=0, font=2, cex=0.7, las=1) 
mtext("cal BP",1, 0, at=5920, adj=0, font=2, cex=0.5, las=1) 
#plot unnoramiles and normalised SPD
par(mar=c(0, 1, 0, 1)) #c(bottom, left, top, right)
ymax <- max(allspd$grid$PrDens)
plot(allspd, xlim=c(6000,3000), xaxt='n', yaxt='n', rescale=TRUE)
plot(allspdn, xlim=c(6000,3000), xaxt='n', type='simple', col="grey20", yaxt='n', add=TRUE, rescale=TRUE)
plot(allspd_shortlived, xlim=c(6000,3000), type='simple', col="darkgreen", xaxt='n', yaxt='n', add=TRUE, rescale=TRUE)
abline(v=seq(5800,3200,-200), lty="dotted", col="white")
text(x=5950, 1, labels="c. SPDs of calibrated radiocarbon dates", font=2, cex=1, adj=c(0,0.7))
text(x=5950, 0.91, labels=paste("n=",nrow(mydates),", sites=",length(unique(mydates$SiteID)),", bins=",length(unique(bins)),sep="", " (all dates)"), font=1, cex=0.8, adj=c(0,0.7))
text(x=5950, 0.83, labels=paste("n=",nrow(shortlived),", sites=",length(unique(shortlived$SiteID)),", bins=",length(unique(bins_shortlived)),sep=""," (shortlived dates)"), font=1, col="darkgreen", cex=0.8, adj=c(0,0.7))
legend(x=5950,0.80, legend=c("SPD unnormalised","SPD normalised","SPD unnormalised (shortlived)"), lty=c("solid","solid","solid"), lwd=c(3,0.5,0.5), col=c("grey90","black","darkgreen"), bty="n", cex=0.8)
box()
#plot the SPD versus a logistic null model
par(mar=c(7, 1, 0, 1)) #c(bottom, left, top, right)
ymax <- max(logisticmod$result$PrDens)*1.1
plot(logisticmod, ylim=c(0,ymax), xlim=c(6000,3000), drawaxes=FALSE)
lines(logisticmod$fit$calBP,logisticmod$fit$PrDens, col="black", lty="dashed", lwd=0.5)
segments(4300,0,4300,ymax, col="red",lwd=2) 
segments(3900,0,3900,ymax, col="red",lwd=2) 
abline(v=seq(5800,3200,-200), lty="dotted", col="white")
text(x=4200, ymax*0.35, labels="4.2 k", font=2, col="red", cex=1.5, adj=c(0,0))
legend(x=5950, ymax*0.94, legend=c("SPD (dates not normalised)","Logistic Model", "95% MC envelope","positive deviation","negative deviation"),col=c(1, "black","lightgrey",rgb(0.7,0,0,0.2),rgb(0,0,0.7,0.2)), lty=c(1,2,1,1,1), lwd=c(0.5,0.5,5,5,5), cex=0.6, bg="white", title="")
text(x=5930, ymax*0.92, labels="d. Logistic Fit", font=2, cex=0.9, adj=c(0,0.7))
text(x=5890, ymax*0.55, cex=0.7, adj=c(0,0.7), labels=substitute(paste(italic(p), "=", x, sep=""), list(x=round(logisticmod$pval,4))))
box()
xticks <- seq(6000,3000,-200)
axis(side=1, at=xticks, labels=xticks, las=2, cex.axis=0.8)# add BP axis
mtext("cal BP",1, 2.4, at=5890, adj=0, font=2, cex=0.6, las=2)
axis(side=1, at=xticks-50, labels=xticks-2000, las=2, cex.axis=0.8,pos=-0.06)# add BC/AD axis
mtext("BC",1, 4.9, at=5840, adj=0, font=2, cex=0.6, las=2) 
dev.off()


#Plot the permutation test of the sites located in different annual rainfall zones (Figure 3)
pdf(file="pdf/Fig3.pdf", width=6, height=4)
layout(matrix(c(1,2), 2, 1, byrow=TRUE), widths=6, heights=c(1.5,2.5))
par(mar=c(0, 0.5, 0, 0.5)) #c(bottom, left, top, right)
par(yaxs="i")
par(xaxs="i")
xticks <- seq(6000,3000,-200)
ymax <- max(perm$envelope[["1"]][,2], perm$observed[["1"]]$PrDens)*1.1
plot(perm, focalm="1", xlim=c(6000,3000), col.obs="green", lwd.obs=1, drawaxes=FALSE)
rect(4300,-1,3900,ymax*1.3,col=rgb(153,76,0,alpha=35, maxColorValue=255), border=NA)  
rect(4250,-1,4150,ymax*1.3,col=rgb(153,76,0,alpha=50, maxColorValue=255), border=NA)
abline(v=seq(5800,3200,-200), lty="dotted", col="white")
legend(x=5900, y=ymax*0.9,legend=c("SPD","95% MC envelope","positive deviation","negative deviation"),col=c(1,"lightgrey",rgb(0.7,0,0,0.2),rgb(0,0,0.7,0.2)),lty=c(1,1,1,1),lwd=c(0.5,5,5,5),cex=0.6, bg="white", title=expression(bold("a. Above 300 mm (annual rainfall)")))
text(x=5900, y=ymax*0.42, labels=paste("n=",nrow(datesp[datesp$Region==1,]),", sites=",length(unique(datesp$SiteName[datesp$Region==1])),", bins=",length(unique(bins[datesp$Region==1])),sep=""), font=1, cex=0.6, adj=c(0,0.7))
text(x=5900, y=ymax*0.35, cex=0.6, adj=c(0,0.7), labels=substitute(paste(italic(p), "=", x, sep=""), list(x=round(min(perm$pValueList["1"],1-perm$pValueList["1"]),3))))
box()
par(mar=c(4.5, 0.5, 0, 0.5)) #c(bottom, left, top, right)
ymax <- max(perm$envelope[["2"]][,2], perm$observed[["2"]]$PrDens)*1.1
plot(perm, focalm="2", xlim=c(6000,3000), col.obs="red", lwd.obs=1, drawaxes=FALSE)
rect(4300,-1,3900,ymax*1.3,col=rgb(153,76,0,alpha=35, maxColorValue=255), border=NA)  
rect(4250,-1,4150,ymax*1.3,col=rgb(153,76,0,alpha=50, maxColorValue=255), border=NA)
abline(v=seq(5800,3200,-200), lty="dotted", col="white")
text(x=4150, ymax*0.8, labels="4.2 k", font=2, col="grey40", cex=1, adj=c(0,0))
legend(x=5900, y=ymax*0.9,legend=c("SPD","95% MC envelope","positive deviation","negative deviation"),col=c(1,"lightgrey",rgb(0.7,0,0,0.2),rgb(0,0,0.7,0.2)),lty=c(1,1,1,1),lwd=c(0.5,5,5,5),cex=0.6, bg="white", title=expression(bold("b. Below 300 mm (annual rainfall)")))
text(x=5900, y=ymax*0.45, labels=paste("n=",nrow(datesp[datesp$Region==2,]),", sites=",length(unique(datesp$SiteName[datesp$Region==2])),", bins=",length(unique(bins[datesp$Region==2])),sep=""), font=1, cex=0.6, adj=c(0,0.7))
text(x=5900, y=ymax*0.38, cex=0.6, adj=c(0,0.7), labels=substitute(paste(italic(p), "=", x, sep=""), list(x=round(min(perm$pValueList["2"],1-perm$pValueList["2"]),3))))
box()
xticks <- seq(6000,3000,-200)
axis(side=1, at=xticks, labels=xticks, las=2, cex.axis=0.6)# add BP axis
mtext("cal BP",1, 2, at=5890, adj=-0.2, font=2, cex=0.5, las=2)
axis(side=1, at=xticks-50, labels=xticks-2000, las=2, cex.axis=0.6,pos=-0.038)# add BC/AD axis
mtext("BC",1, 4, at=5840, adj=-0.2, font=2, cex=0.5, las=2)
par(yaxs="r")
par(xaxs="r")
dev.off()




