
# Install library if not installed -------------------------------------####
if (!('rgdal' %in% installed.packages())){
  install.packages('rgdal')
}

if (!('maptools' %in% installed.packages())){
  install.packages('maptools')
}

## Add libraries (you may need to install these first)
library(rgdal)
library(maptools)

## Load data
sites<-read.csv(file="csv/settlements.csv", sep=",", header=TRUE)


#transform all BCAD dates into BP
StartBP<-(sites$StartDate)+1950
EndBP<-(sites$EndDate)+1950
#add new columns for storing results
sites[,"StartBP"]<-StartBP
sites[,"EndBP"]<-EndBP
#rearrange order of the columns
sites<-sites[c(1:4,9,10,7,5:6)]
sites_above300<-subset(sites, sites$Rain_mm>300)#select the sites located in the annual rainfall zone above 300 mm
sites_below300<-subset(sites, sites$Rain_mm<=300)#select the sites located in the annual rainfall zone below 300 mm

## Create time blocks (100 yrs) and new columns
blockwidth <- 100
brks <- seq(1900,8800,by=blockwidth)
mids <- seq(min(brks)+(blockwidth/2),max(brks)-(blockwidth/2),by=blockwidth)
newcolumns <- paste(brks[1:(length(brks)-1)],"start",sep="")


## Create new tables for storing results
aoristicweights <- sitecounts <- sites
sitecounts[newcolumns] <- NA #add new columns
sitecounts <- sitecounts[,newcolumns] #drop all other columns
aoristicweights[newcolumns] <- NA #add new columns
aoristicweights <- aoristicweights[,newcolumns]#drop all other columns
#sitecounts<-sitecounts[c[56:1]]#invert columns'arrangement
aoristicweights <-sitecounts

## Create new tables for storing results (annual rainfall zone above 300 mm)
aoristicweights_above300 <- sitecounts_above300 <- sites_above300
sitecounts_above300[newcolumns] <- NA #add new columns
sitecounts_above300<- sitecounts_above300[,newcolumns] #drop all other columns
aoristicweights_above300[newcolumns] <- NA #add new columns
aoristicweights_above300 <- aoristicweights_above300[,newcolumns]#drop all other columns
#sitecounts<-sitecounts[c[56:1]]#invert columns'arrangement
aoristicweights_above300 <-sitecounts_above300

## Create new tables for storing results (annual rainfall zone above 300 mm)
aoristicweights_below300 <- sitecounts_below300 <- sites_below300
sitecounts_below300[newcolumns] <- NA #add new columns
sitecounts_below300<- sitecounts_below300[,newcolumns] #drop all other columns
aoristicweights_below300[newcolumns] <- NA #add new columns
aoristicweights_below300 <- aoristicweights_below300[,newcolumns]#drop all other columns
#sitecounts<-sitecounts[c[56:1]]#invert columns'arrangement
aoristicweights_below300 <-sitecounts_below300

## Calculate the duration of each site occupation phase
sites$Duration <- sites$StartBP - sites$EndBP
sites_above300$Duration <- sites_above300$StartBP - sites_above300$EndBP
sites_below300$Duration <- sites_below300$StartBP - sites_below300$EndBP

## Loop through and update timeblocks for each site
for (a in 1:nrow(sites)){
  cat(paste(a,"; ",sep="")) 
  sitestart <- sites$StartBP[a]
  siteend <- sites$EndBP[a]
  siteyears <- seq(siteend,sitestart,by=1)
  siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
  timewts <- siteyearshist$counts/blockwidth
  sitecounts[a,] <- timewts #ordinary counts (but timeblock proportional)
  aoristicweights[a,] <- timewts/sum(timewts) #aoristic weights
}

## Loop through and update timeblocks for each site (annual rainfall zone above 300 mm)
for (a in 1:nrow(sites_above300)){
  cat(paste(a,"; ",sep="")) 
  sitestart <- sites_above300$StartBP[a]
  siteend <- sites_above300$EndBP[a]
  siteyears <- seq(siteend,sitestart,by=1)
  siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
  timewts <- siteyearshist$counts/blockwidth
  sitecounts_above300[a,] <- timewts #ordinary counts (but timeblock proportional)
  aoristicweights_above300[a,] <- timewts/sum(timewts) #aoristic weights
}

## Loop through and update timeblocks for each site (annual rainfall zone below 300 mm)
for (a in 1:nrow(sites_below300)){
  cat(paste(a,"; ",sep="")) 
  sitestart <- sites_below300$StartBP[a]
  siteend <- sites_below300$EndBP[a]
  siteyears <- seq(siteend,sitestart,by=1)
  siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
  timewts <- siteyearshist$counts/blockwidth
  sitecounts_below300[a,] <- timewts #ordinary counts (but timeblock proportional)
  aoristicweights_below300[a,] <- timewts/sum(timewts) #aoristic weights
}

## Randomised Start Dates and Duration ##
## Randomised start date of site occupation phase (uniform). A sites duration randomly generated from a normal distribution with a mean of 200 years and a standard deviations of 50 years is added to the drawn date
## Create time blocks (200 yrs) and new columns
meanDuration <- 200 # mean of randomised site duration
minDuration <- 10
sdDuration <- 50 # standard deviation
sitesdf<-sites
nsim <- 1000 # number of simulations for generating a 95% confidence envelope. This is a time-consuming step. You can also run 100 simulations. 
simdf <- as.data.frame(matrix(ncol=length(newcolumns), nrow=nsim))
colnames(simdf) <- newcolumns
## First loop to create site durations.
for (b in 1:nsim){
  cat(paste(b,"; ",sep="")) 
  tmpsitecounts <- sitecounts
  tmpsitecounts[] <- NA #blank place to put counts
  sitedur <- rnorm(n=nrow(sitesdf),meanDuration,sdDuration)
  while (any(sitedur<minDuration)){
    sitedur[sitedur<minDuration] <- rnorm(n=length(sitedur[sitedur<minDuration]),meanDuration,sdDuration) # enforce truncation at minDuration
  }
}
## Second loop to count results.
for (b in 1:nsim){
  cat(paste(b,"; ",sep=""))
  for (a in 1:nrow(sitesdf)){
    if (sitedur[a]>=sitesdf$Duration[a]){
      sitestart <- sitesdf$StartBP[a]
      siteend <- sitesdf$EndBP[a]
    } else {
      sitestart <- round(runif(1,max=sitesdf$StartBP[a],min=sitesdf$EndBP[a]+sitedur[a]),0)
      siteend <- round(sitestart-sitedur[a])
    }
    siteyears <- seq(siteend,sitestart,by=1)
    siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
    tmpsitecounts[a,] <- siteyearshist$counts/blockwidth
    #tmpsitecounts[tmpsitecounts[,]>0.005]<-1 # tranformation in order to avoid values proportional to time block for sites count
  }
  simdf[b,] <- colSums(tmpsitecounts, na.rm=TRUE)
}

###### annual rainfall above 300 mm
meanDuration <- 200 # mean of randomised site duration
minDuration <- 10
sdDuration <- 50 # standard deviation
sitesdf<-sites_above300
nsim <- 1000 # number of simulations for generating a 95% confidence envelope. This is a time-consuming step. You can also run 100 simulations. 
simdf_above300 <- as.data.frame(matrix(ncol=length(newcolumns), nrow=nsim))
colnames(simdf_above300) <- newcolumns
## First loop to create site durations.
for (b in 1:nsim){
  cat(paste(b,"; ",sep="")) 
  tmpsitecounts <- sitecounts_above300
  tmpsitecounts[] <- NA #blank place to put counts
  sitedur <- rnorm(n=nrow(sitesdf),meanDuration,sdDuration)
  while (any(sitedur<minDuration)){
    sitedur[sitedur<minDuration] <- rnorm(n=length(sitedur[sitedur<minDuration]),meanDuration,sdDuration) # enforce truncation at minDuration
  }
}
## Second loop to count results.
for (b in 1:nsim){
  cat(paste(b,"; ",sep=""))
  for (a in 1:nrow(sitesdf)){
    if (sitedur[a]>=sitesdf$Duration[a]){
      sitestart <- sitesdf$StartBP[a]
      siteend <- sitesdf$EndBP[a]
    } else {
      sitestart <- round(runif(1,max=sitesdf$StartBP[a],min=sitesdf$EndBP[a]+sitedur[a]),0)
      siteend <- round(sitestart-sitedur[a])
    }
    siteyears <- seq(siteend,sitestart,by=1)
    siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
    tmpsitecounts[a,] <- siteyearshist$counts/blockwidth
    #tmpsitecounts[tmpsitecounts[,]>0.005]<-1 # tranformation in order to avoid values proportional to time block for sites count
  }
  simdf_above300[b,] <- colSums(tmpsitecounts, na.rm=TRUE)
}

###### annual rainfall below 300 mm
meanDuration <- 200 # mean of randomised site duration
minDuration <- 10
sdDuration <- 50 # standard deviation
sitesdf<-sites_below300
nsim <- 1000 # number of simulations for generating a 95% confidence envelope. This is a time-consuming step. You can also run 100 simulations. 
simdf_below300 <- as.data.frame(matrix(ncol=length(newcolumns), nrow=nsim))
colnames(simdf_below300) <- newcolumns
## First loop to create site durations.
for (b in 1:nsim){
  cat(paste(b,"; ",sep="")) 
  tmpsitecounts <- sitecounts_below300
  tmpsitecounts[] <- NA #blank place to put counts
  sitedur <- rnorm(n=nrow(sitesdf),meanDuration,sdDuration)
  while (any(sitedur<minDuration)){
    sitedur[sitedur<minDuration] <- rnorm(n=length(sitedur[sitedur<minDuration]),meanDuration,sdDuration) # enforce truncation at minDuration
  }
}
## Second loop to count results.
for (b in 1:nsim){
  cat(paste(b,"; ",sep=""))
  for (a in 1:nrow(sitesdf)){
    if (sitedur[a]>=sitesdf$Duration[a]){
      sitestart <- sitesdf$StartBP[a]
      siteend <- sitesdf$EndBP[a]
    } else {
      sitestart <- round(runif(1,max=sitesdf$StartBP[a],min=sitesdf$EndBP[a]+sitedur[a]),0)
      siteend <- round(sitestart-sitedur[a])
    }
    siteyears <- seq(siteend,sitestart,by=1)
    siteyearshist <- hist(siteyears, breaks=brks, plot=FALSE) 
    tmpsitecounts[a,] <- siteyearshist$counts/blockwidth
    #tmpsitecounts[tmpsitecounts[,]>0.005]<-1 # tranformation in order to avoid values proportional to time block for sites count
  }
  simdf_below300[b,] <- colSums(tmpsitecounts, na.rm=TRUE)
}

## Summarise data
siteBlockSumCounts <- colSums(sitecounts)
siteBlockSumWeights <- colSums(aoristicweights)
funhi <- function(x){ quantile(x, probs=0.975) } # function defining upper limit of 95% confidence envelope 
funlo <- function(x){ quantile(x, probs=0.025) } # function defining lower limit of 95% confidence envelope
hicount <- apply(simdf,2,funhi) # upper limit of 95% confidence envelope of randomised start date of sites 
lowcount <- apply(simdf,2,funlo) # lower limit of 95% confidence envelope of randomised start date of sites 
medcount <- apply(simdf,2,median) # median of 95% confidence envelope of randomised start date of sites 

siteBlockSumCounts_above300 <- colSums(sitecounts_above300)
siteBlockSumWeights_above300 <- colSums(aoristicweights_above300)
hicount_above300 <- apply(simdf_above300,2,funhi) # upper limit of 95% confidence envelope of randomised start date of sites 
lowcount_above300 <- apply(simdf_above300,2,funlo) # lower limit of 95% confidence envelope of randomised start date of sites 
medcount_above300 <- apply(simdf_above300,2,median) # median of 95% confidence envelope of randomised start date of sites 

siteBlockSumCounts_below300 <- colSums(sitecounts_below300)
siteBlockSumWeights_below300 <- colSums(aoristicweights_below300)
hicount_below300 <- apply(simdf_below300,2,funhi) # upper limit of 95% confidence envelope of randomised start date of sites 
lowcount_below300 <- apply(simdf_below300,2,funlo) # lower limit of 95% confidence envelope of randomised start date of sites 
medcount_below300 <- apply(simdf_below300,2,median) # median of 95% confidence envelope of randomised start date of sites 


##  Normalise all proxies between 6000-3000 BP ##
load(file="rda/radiocarbon.RData")#load SPDs

## Sites raw count
count<-siteBlockSumCounts[12:41] # make the vectors having the same length of spd
x<-count
siteBlockSumCounts_norm<-((x-min(x))/(max(x) - min(x)))
## Aoristic weight
aoristic<-siteBlockSumWeights[12:41]
x<-aoristic
siteBlockSumWeights_norm<-((x-min(x))/(max(x) - min(x)))
## SPD of radiocarbon dates 
x<-c(allspd$grid[501:3501,2])
spdY<-((x-min(x))/(max(x) - min(x))) #x-values
spdX<-allspd$grid[501:3501,"calBP"] #y-values

## Sites raw count
count_above300<-siteBlockSumCounts_above300[12:41] # make the vectors having the same length of spd
x<-count_above300
siteBlockSumCounts_above300_norm<-((x-min(x))/(max(x) - min(x)))
## Aoristic weight
aoristic_above300<-siteBlockSumWeights_above300[12:41]
x<-aoristic_above300
siteBlockSumWeights_above300_norm<-((x-min(x))/(max(x) - min(x)))
## SPD of radiocarbon dates (Anatolia)
x<-c(allspd_above300m$grid[501:3501,2])
spdY_above300<-((x-min(x))/(max(x) - min(x))) #x-values
spdX_above300<-allspd_above300m$grid[501:3501,"calBP"] #y-values

## Sites raw count
count_below300<-siteBlockSumCounts_below300[12:41] # make the vectors having the same length of spd
x<-count_below300
siteBlockSumCounts_below300_norm<-((x-min(x))/(max(x) - min(x)))
## Aoristic weight
aoristic_below300<-siteBlockSumWeights_below300[12:41]
x<-aoristic_below300
siteBlockSumWeights_below300_norm<-((x-min(x))/(max(x) - min(x)))
## SPD of radiocarbon dates (Anatolia)
x<-c(allspd_below300m$grid[501:3501,2])
spdY_below300<-((x-min(x))/(max(x) - min(x))) #x-values
spdX_below300<-allspd_below300m$grid[501:3501,"calBP"] #y-values

## Normalise randomised start dates of sites
simdf_norm<-simdf 
simdf_norm[,]<-NA
for (a in 1:nrow(simdf_norm)){
  cat(paste(a,"; ",sep=""))
  x<-simdf[a,]
  tmp_norm<-test <- ((x-min(x))/(max(x) - min(x))) 
  simdf_norm[a,] <- tmp_norm    
}                                                         
simdf_norm[is.na(simdf_norm)] <- 0      
funhi <- function(x){ quantile(x, probs=0.975) }         
funlo <- function(x){ quantile(x, probs=0.025) }          
hicount_norm <- apply(simdf_norm,2,funhi)                 
lowcount_norm <- apply(simdf_norm,2,funlo)                
medcount_norm <- apply(simdf_norm,2,median)               

## Normalise randomised start dates of sites (annual rainfall above 300 mm)
simdf_above300_norm<-simdf_above300 
simdf_above300_norm[,]<-NA
for (a in 1:nrow(simdf_above300_norm)){
  cat(paste(a,"; ",sep=""))
  x<-simdf_above300[a,]
  tmp_norm<-test <- ((x-min(x))/(max(x) - min(x))) 
  simdf_above300_norm[a,] <- tmp_norm    
}                                                         
simdf_above300_norm[is.na(simdf_above300_norm)] <- 0      
funhi <- function(x){ quantile(x, probs=0.975) }         
funlo <- function(x){ quantile(x, probs=0.025) }          
hicount_above300_norm <- apply(simdf_above300_norm,2,funhi)                 
lowcount_above300_norm <- apply(simdf_above300_norm,2,funlo)                
medcount_above300_norm <- apply(simdf_above300_norm,2,median)               


## Normalise randomised start dates of sites (annual rainfall below 300 mm)
simdf_below300_norm<-simdf_below300 
simdf_below300_norm[,]<-NA
for (a in 1:nrow(simdf_below300_norm)){
  cat(paste(a,"; ",sep=""))
  x<-simdf_below300[a,]
  tmp_norm<-test <- ((x-min(x))/(max(x) - min(x))) 
  simdf_below300_norm[a,] <- tmp_norm    
}                                                         
simdf_below300_norm[is.na(simdf_below300_norm)] <- 0      
funhi <- function(x){ quantile(x, probs=0.975) }         
funlo <- function(x){ quantile(x, probs=0.025) }          
hicount_below300_norm <- apply(simdf_below300_norm,2,funhi)                 
lowcount_below300_norm <- apply(simdf_below300_norm,2,funlo)                
medcount_below300_norm <- apply(simdf_below300_norm,2,median)               



## Plot normalised proxies (divided by annual rainfall zone)

#Plot Figure 4
pdf(file="pdf/Fig4.pdf", width=8, height=5.5)
layout(matrix(c(1,2,3), 3, 1, byrow=TRUE), widths=8, heights=c(1.5,1.5,2.5))
par(mar=c(0, 0.5, 0, 0.5)) #c(bottom, left, top, right)
xticks <- seq(6200,2800,-200)
par(mar=c(0, 0.5, 0, 0.5)) #c(bottom, left, top, right)
plot(siteBlockSumCounts_above300_norm~mids[12:41], lty="solid", col="white", cex.axis=0.5, xaxt="n", yaxt="n",type="l", xlab="", ylab="", xlim=c(5900,3100))
rect(4300,-1,3900,2,col=rgb(192,192,192,alpha=120, maxColorValue=255), border=NA)
rect(4250,-1,4150,2,col="gray77", border=NA) 
lines(mids[12:41],siteBlockSumCounts_above300_norm, lty="solid", col="limegreen")
lines(mids[12:41],siteBlockSumCounts_below300_norm, lty="solid", col="red")
abline(v=seq(5800,3200,-200), lwd=0.8, lty="dotted", col="grey30")
legend(x=5850, y=0.93, legend=c("above 300 mm","below 300 mm"),lty=c("solid","solid"), lwd=c(1,1), col=c("limegreen","red"), cex=0.9, bg="transparent",bty="n")
text(x=5860, y=0.99, labels="a. Raw count", font = 2, cex = 1)
text(x=5950, y=0.61, labels=paste("site-phases=",nrow(sitecounts_above300),", sites=",length(unique(sites_above300$Id)),sep=""," (settlements)"), font=1, col="limegreen", cex=0.9, adj=c(0,0.7))
text(x=5950, y=0.52, labels=paste("site-phases=",nrow(sitecounts_below300),", sites=",length(unique(sites_below300$Id)),sep=""," (settlements)"), font=1, col="red", cex=0.9, adj=c(0,0.7))
box()
par(mar=c(0, 0.5, 0, 0.5)) #c(bottom, left, top, right)
plot(siteBlockSumWeights_above300_norm~mids[12:41], lty="dashed", col="white", cex.axis=0.5, xaxt="n", yaxt="n",type="l", xlab="", ylab="", xlim=c(5900,3100))
rect(4300,-1,3900,2,col=rgb(192,192,192,alpha=120, maxColorValue=255), border=NA)
rect(4250,-1,4150,2,col="gray77", border=NA) 
lines(mids[12:41], siteBlockSumWeights_above300_norm, lty="dashed", col="limegreen")
lines(mids[12:41], siteBlockSumWeights_below300_norm, lty="dashed", col="red")
abline(v=seq(5800,3200,-200), lwd=0.8, lty="dotted", col="grey30")
text(x=4150, y=0.8, labels="4.2 k", font=2, col="grey40", cex=1.5, adj=c(0,0))
legend(x=5850, y=0.93, legend=c("above 300 mm","below 300 mm"),lty=c("dashed","dashed"), lwd=c(1,1), col=c("limegreen","red"), cex=0.9, bg="transparent",bty="n")
text(x=5810, y=0.96, labels="b. Aoristic weight", font = 2, cex = 1)
text(x=5950, y=0.61, labels=paste("site-phases=",nrow(sitecounts_above300),", sites=",length(unique(sites_above300$Id)),sep=""," (settlements)"), font=1, col="limegreen", cex=0.9, adj=c(0,0.7))
text(x=5950, y=0.52, labels=paste("site-phases=",nrow(sitecounts_below300),", sites=",length(unique(sites_below300$Id)),sep=""," (settlements)"), font=1, col="red", cex=0.9, adj=c(0,0.7))
box()
par(mar=c(6, 0.5, 0, 0.5)) #c(bottom, left, top, right)
plot(siteBlockSumWeights_above300_norm~mids[12:41], lty="dashed", col="white", cex.axis=0.5, xaxt="n", yaxt="n",type="l", xlab="", ylab="", xlim=c(5900,3100))
rect(4300,-1,3900,2,col=rgb(192,192,192,alpha=120, maxColorValue=255), border=NA)
rect(4250,-1,4150,2,col="gray77", border=NA) 
polygon(x=c(mids,rev(mids)), y=c(hicount_above300_norm,rev(lowcount_above300_norm)), col=rgb(69,139,0,alpha=120, maxColorValue=255), border=NA)
lines(mids, medcount_above300_norm, col="darkgreen")
polygon(x=c(mids,rev(mids)), y=c(hicount_below300_norm,rev(lowcount_below300_norm)), col=rgb(255,64,64,alpha=120, maxColorValue=255), border=NA)
lines(mids, medcount_below300_norm, col="red")
abline(v=seq(5800,3200,-200), lwd=0.8, lty="dotted", col="grey30")
legend(x=5850, y=0.99, legend=c("above 300 mm","below 300 mm","median above 300 mm", "median below 300 mm"),lty=c("solid","solid","solid","solid"), lwd=c(4,4,1,1), col=c("limegreen","red","limegreen","red"), cex=0.9, bg="transparent",bty="n")
text(x=5725, y=1, labels="c. Randomised start date", font = 2, cex = 1)
text(x=5950, y=0.62, labels=paste("site-phases=",nrow(sitecounts_above300),", sites=",length(unique(sites_above300$Id)),sep=""," (settlements)"), font=1, col="limegreen", cex=0.9, adj=c(0,0.7))
text(x=5950, y=0.56, labels=paste("site-phases=",nrow(sitecounts_below300),", sites=",length(unique(sites_below300$Id)),sep=""," (settlements)"), font=1, col="red", cex=0.9, adj=c(0,0.7))
axis(side=1, at=xticks, labels=xticks, las=2, cex.axis=0.75)
mtext("cal BP",1, 2.6, at=5890, adj=0, font=2, cex=0.6, las=2)
axis(side=1, at=xticks-50, labels=xticks-2000, las=2, cex.axis=0.8,pos=-0.28)# add BC/AD axis
mtext("BC",1, 4.9, at=5850, adj=0, font=2, cex=0.6, las=2) 
dev.off()



